@@ -53,7 +53,7 @@ def set_arguments(service):
 
 
     # KAFKA config
-    parser.add_argument('-bs', '--boostrap_server',
+    parser.add_argument('-bs', '--bootstrap_server',
                         help="host:port for kafka consumer/producer, default is localhost:9092",
                         metavar="KAFKA_BOOTSTRAP_SERVER", default='localhost:9092')
     # SQS config
